==> savane-1.0.3.1.tar.gz: savane/frontend/php/my/bookmark_add.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bookmark_add.php,v 1.12 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

site_user_header(array('title'=>_("Add"),'toptab'=>'bookmark'));

print '<h3>'._("Add New Bookmarks").'</h3>';

if ($bookmark_url) 
{
  printf(_("Added bookmark for %s with title %s."),'<b>'.$bookmark_url.'</b>','<b>'.$bookmark_title.'</b>');

  bookmark_add ($bookmark_url, $bookmark_title);
  print "<a href=\"$bookmark_url\">"._("Visit the bookmarked page")."</a> - ";
  print "<a href=\"".$GLOBALS['sys_home']."my/\">"._("Back to your homepage")."</a>";
} 
else 
{

  print "<form method=POST>";
  print _("Bookmark URL").':<br>';
  print '<input type="text" name="bookmark_url" value="http://">';
  print '<p>';
  print _("Bookmark Title").':<br>';
  print '<input type="text" name="bookmark_title" value="'._("My Fav Site").'"></p>';
  print '<p>';
  print '<input type="submit" value=" '._("Submit Form").' "></p>';
  print '</form>';
}

site_user_footer(array());

?>

==> savane-1.0.4.tar.gz: savane/frontend/php/my/bookmark_add.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bookmark_add.php,v 1.13 2004/09/22 08:11:51 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

site_user_header(array('title'=>_("Add"),'toptab'=>'bookmark'));

print '<h3>'._("Add New Bookmarks").'</h3>';

if ($bookmark_url) 
{
  printf(_("Added bookmark for %s with title %s."),'<b>'.$bookmark_url.'</b>','<b>'.$bookmark_title.'</b>');

  bookmark_add ($bookmark_url, $bookmark_title);
  print "<a href=\"$bookmark_url\">"._("Visit the bookmarked page")."</a> - ";
  print "<a href=\"".$GLOBALS['sys_home']."my/\">"._("Back to your homepage")."</a>";
} 
else 
{

  print "<form method=POST>";
  print _("Bookmark URL").':<br />';
  print '<input type="text" name="bookmark_url" value="http://">';
  print '<p>';
  print _("Bookmark Title").':<br />';
  print '<input type="text" name="bookmark_title" value="'._("My Fav Site").'"></p>';
  print '<p>';
  print '<input type="submit" value=" '._("Submit Form").' "></p>';
  print '</form>';
}

site_user_footer(array());

?>
